/***********************************************************************************************************************
* File Name     : I2C.cpp
* Version       : 1.0.0.0
* Device(s)     : Arduino UNO/DUE/...
* Description   : I2C Module Function Source File
***********************************************************************************************************************/
/**********************************************************************************************************************
* History : DD.MM.YYYY Version	Description
*         : 08.12.2023 0.0.0.1	Preliminary Release
*         : 10.06.2024 1.0.0.0  Release
***********************************************************************************************************************/
#include <Arduino.h>
#include <stdint.h>
#include <Wire.h>
#include "I2C.h"
#include "config.h"

/*!
*****************************************************************************
* @brief  write 1byte data to I2C device.  
* @param  i2caddr I2C's address
* @param  data   data or command
*****************************************************************************
*/
void  I2C::write_byte(uint8_t i2caddr, uint8_t data)
{
  delay(1);
  
  // write mode
  Wire.beginTransmission(i2caddr);
  Wire.write(data);  
  Wire.endTransmission(); 
  
}

/*!
*****************************************************************************
* @brief  read ResultData from I2C device. And, you can also send data instead of register address. 
* @param  i2caddr I2C's address
* @param  cmd  Result command 
* @return Result 3byte data which you read
*****************************************************************************
*/
uint32_t I2C::read_result(uint8_t i2caddr, uint8_t cmd)
{
  uint8_t buf[3];
  uint32_t result_data = 0;
  int i = 0;

  delay(1);
  // write mode
  Wire.beginTransmission(i2caddr);
  Wire.write(cmd);  
  Wire.endTransmission(false); 
  
  Wire.requestFrom((int)i2caddr,3,true);
  delay(1);

  // checking data number and reading data
  while (Wire.available()) {
    buf[i] = Wire.read();
    i++;
  }
  
  result_data = (uint32_t)buf[0] *65536 + (uint32_t)buf[1] *256 + (uint32_t)buf[2];
  
  return result_data;
  
}

/*!
*****************************************************************************
* @brief  read RamData from I2C device. And, you can also send data instead of register address. 
* @param  i2caddr I2C's address
* @param  cmd  read ram command 
* @param  regaddr ram address
* @return Result 4byte data which you read
*****************************************************************************
*/
uint32_t I2C::read_ram(uint8_t i2caddr, uint8_t cmd, uint8_t regaddr)
{
  uint8_t buf[4];
  uint32_t read_data = 0;
  int i = 0;
  

  delay(1);
  // write mode
  Wire.beginTransmission(i2caddr);
  Wire.write(cmd);
  Wire.write(regaddr);
  Wire.endTransmission(false); 

  delay(15);
  Wire.requestFrom((int)i2caddr,4,true);
  delay(1);

  // checking data number and reading data
  while (Wire.available()) {
    buf[i] = Wire.read();
    i++;
  }
  
  read_data = (uint32_t)buf[0]*16777216 + (uint32_t)buf[1]*65536 + (uint32_t)buf[2]*256 + (uint32_t)buf[3];

  return read_data;
  
}
