/***********************************************************************************************************************
* File Name     : ope_class.cpp
* Version       : 1.0.0.0
* Device(s)     : Arduino UNO/DUE/...
* Description   : MMS002 Operation Function Source File
***********************************************************************************************************************/
/**********************************************************************************************************************
* History : DD.MM.YYYY Version	Description
*         : 08.12.2023 0.0.0.1	Preliminary Release
*         : 10.06.2024 1.0.0.0	Preliminary Release
***********************************************************************************************************************/
#include <Arduino.h>
#include <stdint.h>
#include "ope_class.h"

/*!
*****************************************************************************
* @brief reset sensor
*****************************************************************************
*/
void OPE::reset_sensor(void)
{
  write_byte(I2CADDR, CMD_RESET);

  delay(10);
}

/*!
*****************************************************************************
* @brief sensor transition shutdown state
*****************************************************************************
*/
void OPE::transition_shutdown(void)
{
  write_byte(I2CADDR, CMD_SHUTDOWN);
}

/*!
*****************************************************************************
* @brief sensor transition shutdown state
*****************************************************************************
*/
void OPE::transition_idle(void)
{
  write_byte(I2CADDR, CMD_IDLE);
  delay(10);
}

/*!
*****************************************************************************
* @brief read RAM
* @param addr I2C's Device RAM Address
*****************************************************************************
*/
uint32_t OPE::read_ram_data(uint8_t addr)
{
//  write_byte(I2CADDR, CMD_READRAM,);
  return read_ram(I2CADDR,CMD_READRAM,addr);
}

/*!
*****************************************************************************
* @brief BANK SW
* @param add_num BANK_SW_CMD add value
*****************************************************************************
*/
void OPE::bank_sw(uint8_t add_num)
{  
  write_byte(I2CADDR, (CMD_BANKSW_ZERO + add_num));
  delay(10);
}

/*!
*****************************************************************************
* @brief start measurement
*****************************************************************************
*/
void OPE::start_active(void)
{
  write_byte(I2CADDR, CMD_ACTIVE);
  delay(3000);
}

/*!
*****************************************************************************
* @brief get measured data result0
* @return I2C's Device 3byte data
*****************************************************************************
*/
uint32_t OPE::read_result_zero(void)
{
  return read_result(I2CADDR,CMD_RESULT_ZERO);
}

/*!
*****************************************************************************
* @brief get measured data result1
* @return I2C's Device 3byte data
*****************************************************************************
*/
uint32_t OPE::read_result_one(void)
{  
  return read_result(I2CADDR,CMD_RESULT_ONE);
}

/*!
*****************************************************************************
* @brief get measured data result2
* @return I2C's Device 3byte data
*****************************************************************************
*/
uint32_t OPE::read_result_two(void)
{  
  return read_result(I2CADDR,CMD_RESULT_TWO);
}
/*!
*****************************************************************************
* @brief get measured data result3
* @return I2C's Device 3byte data
*****************************************************************************
*/
//uint32_t OPE::read_result_three(void)
//{  
//  return read_result(I2CADDR,CMD_RESULT_THREE);
//}
