/***********************************************************************************************************************
* File Name     : ope_class.h
* Version       : 1.0.0.0
* Device(s)     : Arduino UNO/DUE/...
* Description   : MMS002 Operation Function Header File
***********************************************************************************************************************/
/**********************************************************************************************************************
* History : DD.MM.YYYY Version	Description
*         : 08.12.2023 0.0.0.1	Preliminary Release
*         : 10.06.2024 1.0.0.0	Release
***********************************************************************************************************************/
#ifndef _OPE_
#define _OPE_

#include <stdint.h>
#include "I2C.h"

// Class definition
class OPE : public I2C
{
  public:
    static const uint8_t  I2CADDR               = 0x42;
    static const uint8_t  CMD_ACTIVE            = 0xA0;
    static const uint8_t  CMD_RESULT_ZERO       = 0xC0;
    static const uint8_t  CMD_RESULT_ONE        = 0xC2;
    static const uint8_t  CMD_RESULT_TWO        = 0xC4;
    //static const uint8_t  CMD_RESULT_THREE      = 0xC6;
    static const uint8_t  CMD_RESET             = 0x72;
    static const uint8_t  CMD_SHUTDOWN          = 0x90;
    static const uint8_t  CMD_IDLE              = 0x94;
    static const uint8_t  CMD_BANKSW_ZERO       = 0xB0;
    static const uint8_t  CMD_BANKSW_TWO        = 0xB4;
    static const uint8_t  CMD_BANKSW_THREE      = 0xB6;
    static const uint8_t  CMD_READRAM           = 0xD4;
    
    static const uint8_t  RESULT_LEN            = 2;
    uint8_t result_zero_buf[RESULT_LEN];
    uint8_t result_one_buf[RESULT_LEN];
    uint8_t result_two_buf[RESULT_LEN];
    //uint8_t result_three_buf[RESULT_LEN];
    
    void reset_sensor(void);
    void transition_shutdown(void);    
    void transition_idle(void);
    void bank_sw(uint8_t add_num);
    uint32_t read_ram_data(uint8_t addr);

    void start_active(void);
    uint32_t read_result_zero(void);
    uint32_t read_result_one(void);
    uint32_t read_result_two(void);
    //uint32_t read_result_three(void);
};

#endif // _OPE_
